from typing import Any

UNDEFINED: Any

class Key:
    def __new__(cls, *path_args, **kwargs): ...
    def __hash__(self) -> int: ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
    def __lt__(self, other): ...
    def __le__(self, other): ...
    def __gt__(self, other): ...
    def __ge__(self, other): ...
    def __getnewargs__(self): ...
    def parent(self): ...
    def root(self): ...
    def namespace(self): ...
    def project(self): ...
    app: Any
    def id(self): ...
    def string_id(self): ...
    def integer_id(self): ...
    def pairs(self): ...
    def flat(self): ...
    def kind(self): ...
    def reference(self): ...
    def serialized(self): ...
    def urlsafe(self): ...
    def to_legacy_urlsafe(self, location_prefix): ...
    def get(
        self,
        read_consistency: Any | None = ...,
        read_policy: Any | None = ...,
        transaction: Any | None = ...,
        retries: Any | None = ...,
        timeout: Any | None = ...,
        deadline: Any | None = ...,
        use_cache: Any | None = ...,
        use_global_cache: Any | None = ...,
        use_datastore: Any | None = ...,
        global_cache_timeout: Any | None = ...,
        use_memcache: Any | None = ...,
        memcache_timeout: Any | None = ...,
        max_memcache_items: Any | None = ...,
        force_writes: Any | None = ...,
        _options: Any | None = ...,
    ): ...
    def get_async(
        self,
        read_consistency: Any | None = ...,
        read_policy: Any | None = ...,
        transaction: Any | None = ...,
        retries: Any | None = ...,
        timeout: Any | None = ...,
        deadline: Any | None = ...,
        use_cache: Any | None = ...,
        use_global_cache: Any | None = ...,
        use_datastore: Any | None = ...,
        global_cache_timeout: Any | None = ...,
        use_memcache: Any | None = ...,
        memcache_timeout: Any | None = ...,
        max_memcache_items: Any | None = ...,
        force_writes: Any | None = ...,
        _options: Any | None = ...,
    ): ...
    def delete(
        self,
        retries: Any | None = ...,
        timeout: Any | None = ...,
        deadline: Any | None = ...,
        use_cache: Any | None = ...,
        use_global_cache: Any | None = ...,
        use_datastore: Any | None = ...,
        global_cache_timeout: Any | None = ...,
        use_memcache: Any | None = ...,
        memcache_timeout: Any | None = ...,
        max_memcache_items: Any | None = ...,
        force_writes: Any | None = ...,
        _options: Any | None = ...,
    ): ...
    def delete_async(
        self,
        retries: Any | None = ...,
        timeout: Any | None = ...,
        deadline: Any | None = ...,
        use_cache: Any | None = ...,
        use_global_cache: Any | None = ...,
        use_datastore: Any | None = ...,
        global_cache_timeout: Any | None = ...,
        use_memcache: Any | None = ...,
        memcache_timeout: Any | None = ...,
        max_memcache_items: Any | None = ...,
        force_writes: Any | None = ...,
        _options: Any | None = ...,
    ): ...
    @classmethod
    def from_old_key(cls, old_key) -> None: ...
    def to_old_key(self) -> None: ...



from typing import Any

from google.cloud.ndb import model

BlobKey: Any
BLOB_INFO_KIND: str
BLOB_MIGRATION_KIND: str
BLOB_KEY_HEADER: str
BLOB_RANGE_HEADER: str
MAX_BLOB_FETCH_SIZE: int
UPLOAD_INFO_CREATION_HEADER: str
BlobKeyProperty = model.BlobKeyProperty

class BlobFetchSizeTooLargeError:
    def __init__(self, *args, **kwargs) -> None: ...

class BlobInfo:
    def __init__(self, *args, **kwargs) -> None: ...
    @classmethod
    def get(cls, *args, **kwargs) -> None: ...
    @classmethod
    def get_async(cls, *args, **kwargs) -> None: ...
    @classmethod
    def get_multi(cls, *args, **kwargs) -> None: ...
    @classmethod
    def get_multi_async(cls, *args, **kwargs) -> None: ...

class BlobInfoParseError:
    def __init__(self, *args, **kwargs) -> None: ...

class BlobNotFoundError:
    def __init__(self, *args, **kwargs) -> None: ...

class BlobReader:
    def __init__(self, *args, **kwargs) -> None: ...

def create_upload_url(*args, **kwargs) -> None: ...
def create_upload_url_async(*args, **kwargs) -> None: ...

class DataIndexOutOfRangeError:
    def __init__(self, *args, **kwargs) -> None: ...

def delete(*args, **kwargs) -> None: ...
def delete_async(*args, **kwargs) -> None: ...
def delete_multi(*args, **kwargs) -> None: ...
def delete_multi_async(*args, **kwargs) -> None: ...

class Error:
    def __init__(self, *args, **kwargs) -> None: ...

def fetch_data(*args, **kwargs) -> None: ...
def fetch_data_async(*args, **kwargs) -> None: ...

get: Any
get_async: Any
get_multi: Any
get_multi_async: Any

class InternalError:
    def __init__(self, *args, **kwargs) -> None: ...

def parse_blob_info(*args, **kwargs) -> None: ...

class PermissionDeniedError:
    def __init__(self, *args, **kwargs) -> None: ...



from typing import Any

def in_transaction(): ...
def transaction(
    callback, retries=..., read_only: bool = ..., join: bool = ..., xg: bool = ..., propagation: Any | None = ...
): ...
def transaction_async(
    callback, retries=..., read_only: bool = ..., join: bool = ..., xg: bool = ..., propagation: Any | None = ...
): ...
def transaction_async_(
    callback, retries=..., read_only: bool = ..., join: bool = ..., xg: bool = ..., propagation: Any | None = ...
): ...
def transactional(retries=..., read_only: bool = ..., join: bool = ..., xg: bool = ..., propagation: Any | None = ...): ...
def transactional_async(retries=..., read_only: bool = ..., join: bool = ..., xg: bool = ..., propagation: Any | None = ...): ...
def transactional_tasklet(
    retries=..., read_only: bool = ..., join: bool = ..., xg: bool = ..., propagation: Any | None = ...
): ...
def non_transactional(allow_existing: bool = ...): ...



from setuptools import setup

name = "types-google-cloud-ndb"
description = "Typing stubs for google-cloud-ndb"
long_description = '''
## Typing stubs for google-cloud-ndb

This is a PEP 561 type stub package for the `google-cloud-ndb` package.
It can be used by type-checking tools like mypy, PyCharm, pytype etc. to check code
that uses `google-cloud-ndb`. The source for this package can be found at
https://github.com/python/typeshed/tree/main/stubs/google-cloud-ndb. All fixes for
types and metadata should be contributed there.

See https://github.com/python/typeshed/blob/main/README.md for more details.
This package was generated from typeshed commit `d2da97d99c46e873fe2c69da99c100e17b3bc53d`.
'''.lstrip()

setup(name=name,
      version="1.11.5.7",
      description=description,
      long_description=long_description,
      long_description_content_type="text/markdown",
      url="https://github.com/python/typeshed",
      project_urls={
          "GitHub": "https://github.com/python/typeshed",
          "Changes": "https://github.com/typeshed-internal/stub_uploader/blob/main/data/changelogs/google-cloud-ndb.md",
          "Issue tracker": "https://github.com/python/typeshed/issues",
          "Chat": "https://gitter.im/python/typing",
      },
      install_requires=[],
      packages=['google-stubs'],
      package_data={'google-stubs': ['__init__.pyi', 'cloud/__init__.pyi', 'cloud/ndb/__init__.pyi', 'cloud/ndb/_batch.pyi', 'cloud/ndb/_cache.pyi', 'cloud/ndb/_datastore_api.pyi', 'cloud/ndb/_datastore_query.pyi', 'cloud/ndb/_eventloop.pyi', 'cloud/ndb/_options.pyi', 'cloud/ndb/_transaction.pyi', 'cloud/ndb/blobstore.pyi', 'cloud/ndb/client.pyi', 'cloud/ndb/context.pyi', 'cloud/ndb/django_middleware.pyi', 'cloud/ndb/exceptions.pyi', 'cloud/ndb/global_cache.pyi', 'cloud/ndb/key.pyi', 'cloud/ndb/metadata.pyi', 'cloud/ndb/model.pyi', 'cloud/ndb/msgprop.pyi', 'cloud/ndb/polymodel.pyi', 'cloud/ndb/query.pyi', 'cloud/ndb/stats.pyi', 'cloud/ndb/tasklets.pyi', 'cloud/ndb/utils.pyi', 'METADATA.toml']},
      license="Apache-2.0 license",
      classifiers=[
          "License :: OSI Approved :: Apache Software License",
          "Programming Language :: Python :: 3",
          "Typing :: Stubs Only",
      ]
)



from typing import Any

DATASTORE_API_HOST: Any

class Client:
    SCOPE: Any
    namespace: Any
    host: Any
    client_info: Any
    secure: Any
    stub: Any
    def __init__(self, project: Any | None = ..., namespace: Any | None = ..., credentials: Any | None = ...) -> None: ...
    def context(
        self,
        namespace=...,
        cache_policy: Any | None = ...,
        global_cache: Any | None = ...,
        global_cache_policy: Any | None = ...,
        global_cache_timeout_policy: Any | None = ...,
        legacy_data: bool = ...,
    ) -> None: ...
